**CryptoDataHub** is a repository of cryptography-related data available under a free license.

Python Wrapper
--------------

Installation
^^^^^^^^^^^^

.. code:: shell

   pip install cryptodatahub

Support
^^^^^^^

Implementations
"""""""""""""""

-  CPython (2.7, 3.3+)
-  PyPy (2.7, 3.5+)

Operating systems
"""""""""""""""""

-  Linux
-  macOS
-  Windows

License
-------

The code is available under the terms of Mozilla Public License Version 2.0 (MPL 2.0).

A non-comprehensive, but straightforward description of MPL 2.0 can be found at
`Choose an open source license <https://choosealicense.com/licenses#mpl-2.0>`__ website.

Credits
-------

-  `NLnet Foundation <https://nlnet.nl>`__ and `NGI Assure <https://www.assure.ngi.eu>`__, supports the project part of
   the `Next Generation Internet <https://ngi.eu>`__ initiative.
